@@ -37,7 +37,6 @@
 #include "gstmarshal.h"
 #include "gstregistry.h"
 
-static void gst_index_factory_class_init (GstIndexFactoryClass * klass);
 static void gst_index_factory_finalize (GObject * object);
 
 static GstPluginFeatureClass *factory_parent_class = NULL;
@@ -52,7 +51,7 @@ gst_index_factory_class_init (GstIndexFactoryClass * klass)
 
   factory_parent_class = g_type_class_peek_parent (klass);
 
-  gobject_class->finalize = GST_DEBUG_FUNCPTR (gst_index_factory_finalize);
+  gobject_class->finalize = gst_index_factory_finalize;
 }
 
 static void
@@ -87,7 +86,7 @@ gst_index_factory_new (const gchar * name, const gchar * longdesc, GType type)
   GstIndexFactory *factory;
 
   g_return_val_if_fail (name != NULL, NULL);
-  factory = GST_INDEX_FACTORY (g_object_new (GST_TYPE_INDEX_FACTORY, NULL));
+  factory = GST_INDEX_FACTORY (g_object_newv (GST_TYPE_INDEX_FACTORY, 0, NULL));
 
   GST_PLUGIN_FEATURE_NAME (factory) = g_strdup (name);
   if (factory->longdesc)
@@ -160,7 +159,7 @@ gst_index_factory_create (GstIndexFactory * factory)
   if (newfactory == NULL)
     return NULL;
 
-  new = GST_INDEX (g_object_new (newfactory->type, NULL));
+  new = GST_INDEX (g_object_newv (newfactory->type, 0, NULL));
 
   gst_object_unref (newfactory);
 
