@@ -101,7 +101,7 @@ typedef struct BinaryRegistryCache
 static BinaryRegistryCache *
 gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
 {
-  BinaryRegistryCache *cache = g_new0 (BinaryRegistryCache, 1);
+  BinaryRegistryCache *cache = g_slice_new0 (BinaryRegistryCache);
   cache->location = location;
   return cache;
 }
@@ -155,7 +155,7 @@ gst_registry_binary_cache_finish (BinaryRegistryCache * cache, gboolean success)
   }
 
   g_free (cache->mem);
-  g_free (cache);
+  g_slice_free (BinaryRegistryCache, cache);
   return ret;
 }
 
@@ -171,7 +171,7 @@ typedef struct BinaryRegistryCache
 static BinaryRegistryCache *
 gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
 {
-  BinaryRegistryCache *cache = g_new0 (BinaryRegistryCache, 1);
+  BinaryRegistryCache *cache = g_slice_new0 (BinaryRegistryCache);
 
   cache->location = location;
   cache->tmp_location = g_strconcat (location, ".tmpXXXXXX", NULL);
@@ -192,7 +192,7 @@ gst_registry_binary_cache_init (GstRegistry * registry, const char *location)
     if (cache->cache_fd == -1) {
       GST_DEBUG ("g_mkstemp() failed: %s", g_strerror (errno));
       g_free (cache->tmp_location);
-      g_free (cache);
+      g_slice_free (BinaryRegistryCache, cache);
       return NULL;
     }
   }
@@ -241,7 +241,7 @@ gst_registry_binary_cache_finish (BinaryRegistryCache * cache, gboolean success)
   }
 
   g_free (cache->tmp_location);
-  g_free (cache);
+  g_slice_free (BinaryRegistryCache, cache);
   GST_INFO ("Wrote binary registry cache");
   return TRUE;
 
@@ -250,7 +250,7 @@ fail_after_close:
   {
     g_unlink (cache->tmp_location);
     g_free (cache->tmp_location);
-    g_free (cache);
+    g_slice_free (BinaryRegistryCache, cache);
     return FALSE;
   }
 fsync_failed:
@@ -363,7 +363,7 @@ gst_registry_binary_write_cache (GstRegistry * registry, const char *location)
       continue;
 
     if (plugin->flags & GST_PLUGIN_FLAG_CACHED) {
-      struct stat statbuf;
+      GStatBuf statbuf;
 
       if (g_stat (plugin->filename, &statbuf) < 0 ||
           plugin->file_mtime != statbuf.st_mtime ||
@@ -377,6 +377,9 @@ gst_registry_binary_write_cache (GstRegistry * registry, const char *location)
     }
   }
 
+  _priv_gst_registry_chunks_save_global_header (&to_write, registry,
+      priv_gst_plugin_loading_get_whitelist_hash ());
+
   GST_INFO ("Writing binary registry cache");
 
   cache = gst_registry_binary_cache_init (registry, location);
@@ -398,9 +401,8 @@ gst_registry_binary_write_cache (GstRegistry * registry, const char *location)
     gboolean res;
 
     res = gst_registry_binary_write_chunk (cache, cur, &file_position);
-    if (!(cur->flags & GST_REGISTRY_CHUNK_FLAG_CONST))
-      g_free (cur->data);
-    g_free (cur);
+
+    _priv_gst_registry_chunk_free (cur);
     walk->data = NULL;
     if (!res)
       goto fail_free_list;
@@ -418,11 +420,8 @@ fail_free_list:
     for (walk = to_write; walk; walk = g_list_next (walk)) {
       GstRegistryChunk *cur = walk->data;
 
-      if (cur) {
-        if (!(cur->flags & GST_REGISTRY_CHUNK_FLAG_CONST))
-          g_free (cur->data);
-        g_free (cur);
-      }
+      if (cur)
+        _priv_gst_registry_chunk_free (cur);
     }
     g_list_free (to_write);
 
@@ -499,6 +498,7 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
   gsize size;
   GError *err = NULL;
   gboolean res = FALSE;
+  guint32 filter_env_hash = 0;
   gint check_magic_result;
 #ifndef GST_DISABLE_GST_DEBUG
   GTimer *timer = NULL;
@@ -558,6 +558,18 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
     goto Error;
   }
 
+  if (!_priv_gst_registry_chunks_load_global_header (registry, &in,
+          contents + size, &filter_env_hash)) {
+    GST_ERROR ("Couldn't read global header chunk");
+    goto Error;
+  }
+
+  if (filter_env_hash != priv_gst_plugin_loading_get_whitelist_hash ()) {
+    GST_INFO_OBJECT (registry, "Plugin loading filter environment changed, "
+        "ignoring plugin cache to force update with new filter environment");
+    goto done;
+  }
+
   /* check if there are plugins in the file */
   if (G_UNLIKELY (!(((gsize) in + sizeof (GstRegistryChunkPluginElement)) <
               (gsize) contents + size))) {
@@ -579,6 +591,8 @@ gst_registry_binary_read_cache (GstRegistry * registry, const char *location)
     }
   }
 
+done:
+
 #ifndef GST_DISABLE_GST_DEBUG
   g_timer_stop (timer);
   seconds = g_timer_elapsed (timer, NULL);
@@ -597,7 +611,7 @@ Error:
   g_timer_destroy (timer);
 #endif
   if (mapped) {
-#if GLIB_CHECK_VERSION(2,22,0)
+#if GLIB_CHECK_VERSION(2,21,3)
     g_mapped_file_unref (mapped);
 #else
     g_mapped_file_free (mapped);
@@ -609,6 +623,10 @@ Error:
 }
 
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
+gboolean
+gst_registry_xml_read_cache (GstRegistry * registry, const char *location);
+#endif
 /* FIXME 0.11: these symbols are here for backwards compatibility and should
  * be removed or made private */
 gboolean
@@ -617,6 +635,10 @@ gst_registry_xml_read_cache (GstRegistry * registry, const char *location)
   return FALSE;
 }
 
+#ifdef GST_DISABLE_DEPRECATED
+gboolean
+gst_registry_xml_write_cache (GstRegistry * registry, const char *location);
+#endif
 gboolean
 gst_registry_xml_write_cache (GstRegistry * registry, const char *location)
 {
