@@ -289,6 +289,12 @@ gst_registry_chunks_save_feature (GList ** list, GstPluginFeature * feature)
     gst_registry_chunks_save_const_string (list, factory->details.description);
     gst_registry_chunks_save_const_string (list, factory->details.klass);
     gst_registry_chunks_save_const_string (list, factory->details.longname);
+    if (factory->meta_data) {
+      gst_registry_chunks_save_string (list,
+          gst_structure_to_string (factory->meta_data));
+    } else {
+      gst_registry_chunks_save_const_string (list, "");
+    }
   } else if (GST_IS_TYPE_FIND_FACTORY (feature)) {
     GstRegistryChunkTypeFindFactory *tff;
     GstTypeFindFactory *factory = GST_TYPE_FIND_FACTORY (feature);
@@ -447,6 +453,8 @@ _priv_gst_registry_chunks_save_plugin (GList ** list, GstRegistry * registry,
   }
 
   /* pack plugin element strings */
+  gst_registry_chunks_save_const_string (list,
+      (plugin->desc.release_datetime) ? plugin->desc.release_datetime : "");
   gst_registry_chunks_save_const_string (list, plugin->desc.origin);
   gst_registry_chunks_save_const_string (list, plugin->desc.package);
   gst_registry_chunks_save_const_string (list, plugin->desc.source);
@@ -565,6 +573,8 @@ gst_registry_chunks_load_feature (GstRegistry * registry, gchar ** in,
     GstRegistryChunkElementFactory *ef;
     guint n;
     GstElementFactory *factory = GST_ELEMENT_FACTORY_CAST (feature);
+    gchar *str;
+    const gchar *meta_data_str;
 
     align (*in);
     GST_LOG ("Reading/casting for GstRegistryChunkElementFactory at address %p",
@@ -573,6 +583,16 @@ gst_registry_chunks_load_feature (GstRegistry * registry, gchar ** in,
     pf = (GstRegistryChunkPluginFeature *) ef;
 
     /* unpack element factory strings */
+    unpack_string_nocopy (*in, meta_data_str, end, fail);
+    if (meta_data_str && *meta_data_str) {
+      factory->meta_data = gst_structure_from_string (meta_data_str, NULL);
+      if (!factory->meta_data) {
+        GST_ERROR
+            ("Error when trying to deserialize structure for metadata '%s'",
+            meta_data_str);
+        goto fail;
+      }
+    }
     unpack_string (*in, factory->details.longname, end, fail);
     unpack_string (*in, factory->details.klass, end, fail);
     unpack_string (*in, factory->details.description, end, fail);
@@ -772,13 +792,15 @@ _priv_gst_registry_chunks_load_plugin (GstRegistry * registry, gchar ** in,
 
   /* unpack plugin element strings */
   unpack_const_string (*in, plugin->desc.name, end, fail);
-  unpack_string (*in, plugin->desc.description, end, fail);
+  unpack_const_string (*in, plugin->desc.description, end, fail);
   unpack_string (*in, plugin->filename, end, fail);
   unpack_const_string (*in, plugin->desc.version, end, fail);
   unpack_const_string (*in, plugin->desc.license, end, fail);
   unpack_const_string (*in, plugin->desc.source, end, fail);
   unpack_const_string (*in, plugin->desc.package, end, fail);
   unpack_const_string (*in, plugin->desc.origin, end, fail);
+  unpack_const_string (*in, plugin->desc.release_datetime, end, fail);
+
   GST_LOG ("read strings for name='%s'", plugin->desc.name);
   GST_LOG ("  desc.description='%s'", plugin->desc.description);
   GST_LOG ("  filename='%s'", plugin->filename);
@@ -787,6 +809,10 @@ _priv_gst_registry_chunks_load_plugin (GstRegistry * registry, gchar ** in,
   GST_LOG ("  desc.source='%s'", plugin->desc.source);
   GST_LOG ("  desc.package='%s'", plugin->desc.package);
   GST_LOG ("  desc.origin='%s'", plugin->desc.origin);
+  GST_LOG ("  desc.datetime=%s", plugin->desc.release_datetime);
+
+  if (plugin->desc.release_datetime[0] == '\0')
+    plugin->desc.release_datetime = NULL;
 
   /* unpack cache data */
   unpack_string_nocopy (*in, cache_str, end, fail);
@@ -837,3 +863,39 @@ fail:
   GST_INFO ("Reading plugin failed after %u bytes", (guint) (end - start));
   return FALSE;
 }
+
+void
+_priv_gst_registry_chunks_save_global_header (GList ** list,
+    GstRegistry * registry, guint32 filter_env_hash)
+{
+  GstRegistryChunkGlobalHeader *hdr;
+  GstRegistryChunk *chk;
+
+  hdr = g_slice_new (GstRegistryChunkGlobalHeader);
+  chk = gst_registry_chunks_make_data (hdr,
+      sizeof (GstRegistryChunkGlobalHeader));
+
+  hdr->filter_env_hash = filter_env_hash;
+
+  *list = g_list_prepend (*list, chk);
+
+  GST_LOG ("Saved global header (filter_env_hash=0x%08x)", filter_env_hash);
+}
+
+gboolean
+_priv_gst_registry_chunks_load_global_header (GstRegistry * registry,
+    gchar ** in, gchar * end, guint32 * filter_env_hash)
+{
+  GstRegistryChunkGlobalHeader *hdr;
+
+  align (*in);
+  GST_LOG ("Reading/casting for GstRegistryChunkGlobalHeader at %p", *in);
+  unpack_element (*in, hdr, GstRegistryChunkGlobalHeader, end, fail);
+  *filter_env_hash = hdr->filter_env_hash;
+  return TRUE;
+
+  /* Errors */
+fail:
+  GST_WARNING ("Reading global header failed");
+  return FALSE;
+}
