@@ -127,6 +127,10 @@ _gst_tag_initialize (void)
       _("The artist of the entire album, as it should be sorted"), NULL);
   gst_tag_register (GST_TAG_DATE, GST_TAG_FLAG_META, GST_TYPE_DATE,
       _("date"), _("date the data was created (as a GDate structure)"), NULL);
+  gst_tag_register (GST_TAG_DATE_TIME, GST_TAG_FLAG_META, GST_TYPE_DATE_TIME,
+      _("datetime"),
+      _("date and time the data was created (as a GstDateTime structure)"),
+      NULL);
   gst_tag_register (GST_TAG_GENRE, GST_TAG_FLAG_META,
       G_TYPE_STRING,
       _("genre"),
@@ -282,6 +286,38 @@ _gst_tag_initialize (void)
       G_TYPE_DOUBLE, _("geo location elevation"),
       _("geo elevation of where the media has been recorded or produced in "
           "meters according to WGS84 (zero is average sea level)"), NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_COUNTRY, GST_TAG_FLAG_META,
+      G_TYPE_STRING, _("geo location country"),
+      _("country (english name) where the media has been recorded "
+          "or produced"), NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_CITY, GST_TAG_FLAG_META,
+      G_TYPE_STRING, _("geo location city"),
+      _("city (english name) where the media has been recorded "
+          "or produced"), NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_SUBLOCATION, GST_TAG_FLAG_META,
+      G_TYPE_STRING, _("geo location sublocation"),
+      _("a location whithin a city where the media has been produced "
+          "or created (e.g. the neighborhood)"), NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_HORIZONTAL_ERROR, GST_TAG_FLAG_META,
+      G_TYPE_DOUBLE, _("geo location horizontal error"),
+      _("expected error of the horizontal positioning measures (in meters)"),
+      NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_MOVEMENT_SPEED, GST_TAG_FLAG_META,
+      G_TYPE_DOUBLE, _("geo location movement speed"),
+      _("movement speed of the capturing device while performing the capture "
+          "in m/s"), NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_MOVEMENT_DIRECTION, GST_TAG_FLAG_META,
+      G_TYPE_DOUBLE, _("geo location movement direction"),
+      _("indicates the movement direction of the device performing the capture"
+          " of a media. It is represented as degrees in floating point "
+          "representation, 0 means the geographic north, and increases "
+          "clockwise"), NULL);
+  gst_tag_register (GST_TAG_GEO_LOCATION_CAPTURE_DIRECTION, GST_TAG_FLAG_META,
+      G_TYPE_DOUBLE, _("geo location capture direction"),
+      _("indicates the direction the device is pointing to when capturing "
+          " a media. It is represented as degrees in floating point "
+          " representation, 0 means the geographic north, and increases "
+          "clockwise"), NULL);
   gst_tag_register (GST_TAG_SHOW_NAME, GST_TAG_FLAG_META, G_TYPE_STRING,
       /* TRANSLATORS: 'show name' = 'TV/radio/podcast show name' here */
       _("show name"),
@@ -311,6 +347,24 @@ _gst_tag_initialize (void)
       _("Groups related media that spans multiple tracks, like the different "
           "pieces of a concerto. It is a higher level than a track, "
           "but lower than an album"), NULL);
+  gst_tag_register (GST_TAG_USER_RATING, GST_TAG_FLAG_META, G_TYPE_UINT,
+      _("user rating"),
+      _("Rating attributed by a user. The higher the rank, "
+          "the more the user likes this media"), NULL);
+  gst_tag_register (GST_TAG_DEVICE_MANUFACTURER, GST_TAG_FLAG_META,
+      G_TYPE_STRING, _("device manufacturer"),
+      _("Manufacturer of the device used to create this media"), NULL);
+  gst_tag_register (GST_TAG_DEVICE_MODEL, GST_TAG_FLAG_META, G_TYPE_STRING,
+      _("device model"),
+      _("Model of the device used to create this media"), NULL);
+  gst_tag_register (GST_TAG_APPLICATION_NAME, GST_TAG_FLAG_META, G_TYPE_STRING,
+      _("application name"), _("Application used to create the media"), NULL);
+  gst_tag_register (GST_TAG_APPLICATION_DATA, GST_TAG_FLAG_META,
+      GST_TYPE_BUFFER, _("application data"),
+      _("Arbitrary application data to be serialized into the media"), NULL);
+  gst_tag_register (GST_TAG_IMAGE_ORIENTATION, GST_TAG_FLAG_META, G_TYPE_STRING,
+      _("image orientation"),
+      _("How the image should be rotated or flipped before display"), NULL);
 }
 
 /**
@@ -348,11 +402,10 @@ gst_tag_merge_strings_with_comma (GValue * dest, const GValue * src)
   count = gst_value_list_get_size (src);
   str = g_string_new (g_value_get_string (gst_value_list_get_value (src, 0)));
   for (i = 1; i < count; i++) {
-    /* seperator between two string */
-    str = g_string_append (str, _(", "));
-    str =
-        g_string_append (str, g_value_get_string (gst_value_list_get_value (src,
-                1)));
+    /* separator between two strings */
+    g_string_append (str, _(", "));
+    g_string_append (str,
+        g_value_get_string (gst_value_list_get_value (src, i)));
   }
 
   g_value_init (dest, G_TYPE_STRING);
@@ -423,7 +476,7 @@ gst_tag_register (const gchar * name, GstTagFlag flag, GType type,
     return;
   }
 
-  info = g_new (GstTagInfo, 1);
+  info = g_slice_new (GstTagInfo);
   info->flag = flag;
   info->type = type;
   info->nick = g_strdup (nick);
@@ -945,8 +998,12 @@ gst_tag_list_add_valist (GstTagList * list, GstTagMergeMode mode,
       g_warning ("unknown tag '%s'", tag);
       return;
     }
+#if GLIB_CHECK_VERSION(2,23,3)
+    G_VALUE_COLLECT_INIT (&value, info->type, var_args, 0, &error);
+#else
     g_value_init (&value, info->type);
     G_VALUE_COLLECT (&value, var_args, 0, &error);
+#endif
     if (error) {
       g_warning ("%s: %s", G_STRLOC, error);
       g_free (error);
@@ -1559,6 +1616,44 @@ TAG_MERGE_FUNCS (pointer, gpointer, (*value != NULL))
  */
 TAG_MERGE_FUNCS (string, gchar *, (*value != NULL && **value != '\0'))
 
+/*
+ *FIXME 0.11: Instead of _peek (non-copy) and _get (copy), we could have
+ *            _get (non-copy) and _dup (copy) for strings, seems more
+ *            widely used
+ */
+/**
+ * gst_tag_list_peek_string_index:
+ * @list: a #GstTagList to get the tag from
+ * @tag: tag to read out
+ * @index: number of entry to read out
+ * @value: location for the result
+ *
+ * Peeks at the value that is at the given index for the given tag in the given
+ * list.
+ *
+ * The resulting string in @value will be in UTF-8 encoding and doesn't need
+ * to be freed by the caller. The returned string is also guaranteed to
+ * be non-NULL and non-empty.
+ *
+ * Returns: TRUE, if a value was set, FALSE if the tag didn't exist in the
+ *              given list.
+ */
+gboolean
+gst_tag_list_peek_string_index (const GstTagList * list,
+    const gchar * tag, guint index, const gchar ** value)
+{
+  const GValue *v;
+
+  g_return_val_if_fail (GST_IS_TAG_LIST (list), FALSE);
+  g_return_val_if_fail (tag != NULL, FALSE);
+  g_return_val_if_fail (value != NULL, FALSE);
+
+  if ((v = gst_tag_list_get_value_index (list, tag, index)) == NULL)
+    return FALSE;
+  *value = g_value_get_string (v);
+  return *value != NULL && **value != '\0';
+}
+
 /**
  * gst_tag_list_get_date:
  * @list: a #GstTagList to get the tag from
@@ -1619,6 +1714,71 @@ gst_tag_list_get_date_index (const GstTagList * list,
   return (*value != NULL);
 }
 
+/**
+ * gst_tag_list_get_date_time:
+ * @list: a #GstTagList to get the tag from
+ * @tag: tag to read out
+ * @value: address of a #GstDateTime pointer variable to store the result into
+ *
+ * Copies the first datetime for the given tag in the taglist into the variable
+ * pointed to by @value. Unref the date with gst_date_time_unref() when
+ * it is no longer needed.
+ *
+ * Returns: TRUE, if a datetime was copied, FALSE if the tag didn't exist in the
+ *              given list or if it was #NULL.
+ * Since: 0.10.31
+ */
+gboolean
+gst_tag_list_get_date_time (const GstTagList * list, const gchar * tag,
+    GstDateTime ** value)
+{
+  GValue v = { 0, };
+
+  g_return_val_if_fail (GST_IS_TAG_LIST (list), FALSE);
+  g_return_val_if_fail (tag != NULL, FALSE);
+  g_return_val_if_fail (value != NULL, FALSE);
+
+  if (!gst_tag_list_copy_value (&v, list, tag))
+    return FALSE;
+
+  g_return_val_if_fail (GST_VALUE_HOLDS_DATE_TIME (&v), FALSE);
+
+  *value = (GstDateTime *) g_value_dup_boxed (&v);
+  g_value_unset (&v);
+  return (*value != NULL);
+}
+
+/**
+ * gst_tag_list_get_date_time_index:
+ * @list: a #GstTagList to get the tag from
+ * @tag: tag to read out
+ * @index: number of entry to read out
+ * @value: location for the result
+ *
+ * Gets the datetime that is at the given index for the given tag in the given
+ * list and copies it into the variable pointed to by @value. Unref the datetime
+ * with gst_date_time_unref() when it is no longer needed.
+ *
+ * Returns: TRUE, if a value was copied, FALSE if the tag didn't exist in the
+ *              given list or if it was #NULL.
+ * Since: 0.10.31
+ */
+gboolean
+gst_tag_list_get_date_time_index (const GstTagList * list,
+    const gchar * tag, guint index, GstDateTime ** value)
+{
+  const GValue *v;
+
+  g_return_val_if_fail (GST_IS_TAG_LIST (list), FALSE);
+  g_return_val_if_fail (tag != NULL, FALSE);
+  g_return_val_if_fail (value != NULL, FALSE);
+
+  if ((v = gst_tag_list_get_value_index (list, tag, index)) == NULL)
+    return FALSE;
+  *value = (GstDateTime *) g_value_dup_boxed (v);
+  return (*value != NULL);
+}
+
 /**
  * gst_tag_list_get_buffer:
  * @list: a #GstTagList to get the tag from
