@@ -101,6 +101,16 @@ G_BEGIN_DECLS
  */
 #define GST_VALUE_HOLDS_INT_RANGE(x)    (G_VALUE_HOLDS((x), gst_int_range_get_type ()))
 
+/**
+ * GST_VALUE_HOLDS_INT64_RANGE:
+ * @x: the #GValue to check
+ *
+ * Checks if the given #GValue contains a #GST_TYPE_INT64_RANGE value.
+ *
+ * Since: 0.10.31
+ */
+#define GST_VALUE_HOLDS_INT64_RANGE(x)    (G_VALUE_HOLDS((x), gst_int64_range_get_type ()))
+
 /**
  * GST_VALUE_HOLDS_DOUBLE_RANGE:
  * @x: the #GValue to check
@@ -175,6 +185,16 @@ G_BEGIN_DECLS
  */
 #define GST_VALUE_HOLDS_DATE(x)         (G_VALUE_HOLDS((x), gst_date_get_type ()))
 
+/**
+ * GST_VALUE_HOLDS_DATE_TIME:
+ * @x: the #GValue to check
+ *
+ * Checks if the given #GValue contains a #GST_TYPE_DATE_TIME value.
+ *
+ * Since: 0.10.31
+ */
+#define GST_VALUE_HOLDS_DATE_TIME(x)    (G_VALUE_HOLDS((x), gst_date_time_get_type ()))
+
 /**
  * GST_TYPE_FOURCC:
  *
@@ -193,6 +213,17 @@ G_BEGIN_DECLS
  */
 #define GST_TYPE_INT_RANGE               gst_int_range_get_type ()
 
+/**
+ * GST_TYPE_INT64_RANGE:
+ *
+ * a #GValue type that represents an #gint64 range
+ *
+ * Returns: the #GType of GstInt64Range
+ *
+ * Since: 0.10.31
+ */
+#define GST_TYPE_INT64_RANGE             gst_int64_range_get_type ()
+
 /**
  * GST_TYPE_DOUBLE_RANGE:
  *
@@ -259,6 +290,17 @@ G_BEGIN_DECLS
 
 #define GST_TYPE_DATE                    gst_date_get_type ()
 
+/**
+ * GST_TYPE_DATE_TIME:
+ *
+ * a boxed #GValue type for #GstDateTime that represents a date and time.
+ *
+ * Returns: the #GType of GstDateTime
+ * Since: 0.10.31
+ */
+
+#define GST_TYPE_DATE_TIME               gst_date_time_get_type ()
+
 /**
  * GST_VALUE_LESS_THAN:
  *
@@ -293,10 +335,10 @@ G_BEGIN_DECLS
 
 /**
  * GstValueCompareFunc:
- * @value1: first value for comparission
- * @value2: second value for comparission
+ * @value1: first value for comparison
+ * @value2: second value for comparison
  *
- * Used together with gst_value_compare() to compare #GValues.
+ * Used together with gst_value_compare() to compare #GValue items.
  *
  * Returns: one of GST_VALUE_LESS_THAN, GST_VALUE_EQUAL, GST_VALUE_GREATER_THAN
  * or GST_VALUE_UNORDERED
@@ -351,7 +393,7 @@ typedef gboolean (* GstValueUnionFunc)       (GValue       *dest,
  * type. If the intersection is non-empty, the result is
  * placed in @dest and TRUE is returned.  If the intersection is
  * empty, @dest is unmodified and FALSE is returned.
- * Register a new implementation with gst_value_register_intersection_func().
+ * Register a new implementation with gst_value_register_intersect_func().
  *
  * Returns: %TRUE if the values can intersect
  */
@@ -395,6 +437,7 @@ struct _GstValueTable {
 };
 
 GType gst_int_range_get_type (void);
+GType gst_int64_range_get_type (void);
 GType gst_double_range_get_type (void);
 GType gst_fraction_range_get_type (void);
 GType gst_fourcc_get_type (void);
@@ -403,6 +446,7 @@ GType gst_value_list_get_type (void);
 GType gst_value_array_get_type (void);
 
 GType gst_date_get_type (void);
+GType gst_date_time_get_type (void);
 
 void		gst_value_register		(const GstValueTable   *table);
 void		gst_value_init_and_copy		(GValue                *dest,
@@ -447,6 +491,13 @@ void		gst_value_set_int_range		(GValue		*value,
 gint		gst_value_get_int_range_min	(const GValue	*value);
 gint		gst_value_get_int_range_max	(const GValue	*value);
 
+/* int64 range */
+void		gst_value_set_int64_range      	(GValue		*value,
+						 gint64		start,
+						 gint64		end);
+gint64		gst_value_get_int64_range_min	(const GValue	*value);
+gint64		gst_value_get_int64_range_max	(const GValue	*value);
+
 /* double range */
 void		gst_value_set_double_range	(GValue		*value,
 						 gdouble	start,
