@@ -1,6 +1,7 @@
-/* GStreamer
+/* GStreamer byte reader
  *
  * Copyright (C) 2008 Sebastian Dröge <sebastian.droege@collabora.co.uk>.
+ * Copyright (C) 2009 Tim-Philipp Müller <tim centricular net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -22,6 +23,7 @@
 #include "config.h"
 #endif
 
+#define GST_BYTE_READER_DISABLE_INLINES
 #include "gstbytereader.h"
 
 #include <string.h>
@@ -177,9 +179,7 @@ gst_byte_reader_set_pos (GstByteReader * reader, guint pos)
 guint
 gst_byte_reader_get_pos (const GstByteReader * reader)
 {
-  g_return_val_if_fail (reader != NULL, 0);
-
-  return reader->byte;
+  return _gst_byte_reader_get_pos_inline (reader);
 }
 
 /**
@@ -195,11 +195,28 @@ gst_byte_reader_get_pos (const GstByteReader * reader)
 guint
 gst_byte_reader_get_remaining (const GstByteReader * reader)
 {
-  g_return_val_if_fail (reader != NULL, 0);
-
-  return reader->size - reader->byte;
+  return _gst_byte_reader_get_remaining_inline (reader);
 }
 
+/**
+ * gst_byte_reader_get_size:
+ * @reader: a #GstByteReader instance
+ *
+ * Returns the total number of bytes of a #GstByteReader instance.
+ *
+ * Returns: The total number of bytes of @reader instance.
+ * 
+ * Since: 0.10.26
+ */
+guint
+gst_byte_reader_get_size (const GstByteReader * reader)
+{
+  return _gst_byte_reader_get_size_inline (reader);
+}
+
+#define gst_byte_reader_get_remaining _gst_byte_reader_get_remaining_inline
+#define gst_byte_reader_get_size _gst_byte_reader_get_size_inline
+
 /**
  * gst_byte_reader_skip:
  * @reader: a #GstByteReader instance
@@ -214,14 +231,7 @@ gst_byte_reader_get_remaining (const GstByteReader * reader)
 gboolean
 gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
 {
-  g_return_val_if_fail (reader != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < nbytes)
-    return FALSE;
-
-  reader->byte += nbytes;
-
-  return TRUE;
+  return _gst_byte_reader_skip_inline (reader, nbytes);
 }
 
 /**
@@ -253,7 +263,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint8 to store the result
  *
- * Read a signed 8 bit integer into @val but keep the current position.
+ * Read an unsigned 8 bit integer into @val but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
  * 
@@ -303,7 +313,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint16 to store the result
  *
- * Read a signed 16 bit little endian integer into @val
+ * Read an unsigned 16 bit little endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -355,7 +365,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint16 to store the result
  *
- * Read a signed 16 bit big endian integer into @val
+ * Read an unsigned 16 bit big endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -407,7 +417,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint32 to store the result
  *
- * Read a signed 24 bit little endian integer into @val
+ * Read an unsigned 24 bit little endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -459,7 +469,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint32 to store the result
  *
- * Read a signed 24 bit big endian integer into @val
+ * Read an unsigned 24 bit big endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -512,7 +522,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint32 to store the result
  *
- * Read a signed 32 bit little endian integer into @val
+ * Read an unsigned 32 bit little endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -564,7 +574,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint32 to store the result
  *
- * Read a signed 32 bit big endian integer into @val
+ * Read an unsigned 32 bit big endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -616,7 +626,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint64 to store the result
  *
- * Read a signed 64 bit little endian integer into @val
+ * Read an unsigned 64 bit little endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -668,7 +678,7 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #guint64 to store the result
  *
- * Read a signed 64 bit big endian integer into @val
+ * Read an unsigned 64 bit big endian integer into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -689,313 +699,50 @@ gst_byte_reader_skip (GstByteReader * reader, guint nbytes)
  * Since: 0.10.22
  */
 
-#define GST_BYTE_READER_READ_INTS(bits) \
+#define GST_BYTE_READER_PEEK_GET(bits,type,name) \
 gboolean \
-gst_byte_reader_get_uint##bits##_le (GstByteReader *reader, guint##bits *val) \
+gst_byte_reader_get_##name (GstByteReader * reader, type * val) \
 { \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_LE (&reader->data[reader->byte]); \
-  reader->byte += bits / 8; \
-  return TRUE; \
+  return _gst_byte_reader_get_##name##_inline (reader, val); \
 } \
 \
 gboolean \
-gst_byte_reader_get_uint##bits##_be (GstByteReader *reader, guint##bits *val) \
+gst_byte_reader_peek_##name (const GstByteReader * reader, type * val) \
 { \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_BE (&reader->data[reader->byte]); \
-  reader->byte += bits / 8; \
-  return TRUE; \
-} \
-\
-gboolean \
-gst_byte_reader_get_int##bits##_le (GstByteReader *reader, gint##bits *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_LE (&reader->data[reader->byte]); \
-  reader->byte += bits / 8; \
-  return TRUE; \
-} \
-\
-gboolean \
-gst_byte_reader_get_int##bits##_be (GstByteReader *reader, gint##bits *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_BE (&reader->data[reader->byte]); \
-  reader->byte += bits / 8; \
-  return TRUE; \
-} \
-gboolean \
-gst_byte_reader_peek_uint##bits##_le (GstByteReader *reader, guint##bits *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_LE (&reader->data[reader->byte]); \
-  return TRUE; \
-} \
-\
-gboolean \
-gst_byte_reader_peek_uint##bits##_be (GstByteReader *reader, guint##bits *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_BE (&reader->data[reader->byte]); \
-  return TRUE; \
-} \
-\
-gboolean \
-gst_byte_reader_peek_int##bits##_le (GstByteReader *reader, gint##bits *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_LE (&reader->data[reader->byte]); \
-  return TRUE; \
-} \
-\
-gboolean \
-gst_byte_reader_peek_int##bits##_be (GstByteReader *reader, gint##bits *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_UINT##bits##_BE (&reader->data[reader->byte]); \
-  return TRUE; \
+  return _gst_byte_reader_peek_##name##_inline (reader, val); \
 }
 
+/* *INDENT-OFF* */
 
-GST_BYTE_READER_READ_INTS (16);
-GST_BYTE_READER_READ_INTS (32);
-GST_BYTE_READER_READ_INTS (64);
+GST_BYTE_READER_PEEK_GET(8,guint8,uint8)
+GST_BYTE_READER_PEEK_GET(8,gint8,int8)
 
-gboolean
-gst_byte_reader_get_uint8 (GstByteReader * reader, guint8 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
+GST_BYTE_READER_PEEK_GET(16,guint16,uint16_le)
+GST_BYTE_READER_PEEK_GET(16,guint16,uint16_be)
+GST_BYTE_READER_PEEK_GET(16,gint16,int16_le)
+GST_BYTE_READER_PEEK_GET(16,gint16,int16_be)
 
-  if (reader->byte >= reader->size)
-    return FALSE;
+GST_BYTE_READER_PEEK_GET(24,guint32,uint24_le)
+GST_BYTE_READER_PEEK_GET(24,guint32,uint24_be)
+GST_BYTE_READER_PEEK_GET(24,gint32,int24_le)
+GST_BYTE_READER_PEEK_GET(24,gint32,int24_be)
 
-  *val = GST_READ_UINT8 (&reader->data[reader->byte]);
-  reader->byte++;
-  return TRUE;
-}
+GST_BYTE_READER_PEEK_GET(32,guint32,uint32_le)
+GST_BYTE_READER_PEEK_GET(32,guint32,uint32_be)
+GST_BYTE_READER_PEEK_GET(32,gint32,int32_le)
+GST_BYTE_READER_PEEK_GET(32,gint32,int32_be)
 
-gboolean
-gst_byte_reader_get_int8 (GstByteReader * reader, gint8 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (reader->byte >= reader->size)
-    return FALSE;
-
-  *val = GST_READ_UINT8 (&reader->data[reader->byte]);
-  reader->byte++;
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_peek_uint8 (GstByteReader * reader, guint8 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (reader->byte >= reader->size)
-    return FALSE;
-
-  *val = GST_READ_UINT8 (&reader->data[reader->byte]);
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_peek_int8 (GstByteReader * reader, gint8 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (reader->byte >= reader->size)
-    return FALSE;
-
-  *val = GST_READ_UINT8 (&reader->data[reader->byte]);
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_get_uint24_le (GstByteReader * reader, guint32 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  *val = GST_READ_UINT24_LE (&reader->data[reader->byte]);
-  reader->byte += 3;
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_get_uint24_be (GstByteReader * reader, guint32 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  *val = GST_READ_UINT24_BE (&reader->data[reader->byte]);
-  reader->byte += 3;
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_get_int24_le (GstByteReader * reader, gint32 * val)
-{
-  guint32 ret;
-
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  ret = GST_READ_UINT24_LE (&reader->data[reader->byte]);
-  if (ret & 0x00800000)
-    ret |= 0xff000000;
-
-  reader->byte += 3;
-
-  *val = ret;
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_get_int24_be (GstByteReader * reader, gint32 * val)
-{
-  guint32 ret;
-
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  ret = GST_READ_UINT24_BE (&reader->data[reader->byte]);
-  if (ret & 0x00800000)
-    ret |= 0xff000000;
-
-  reader->byte += 3;
-
-  *val = ret;
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_peek_uint24_le (GstByteReader * reader, guint32 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  *val = GST_READ_UINT24_LE (&reader->data[reader->byte]);
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_peek_uint24_be (GstByteReader * reader, guint32 * val)
-{
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  *val = GST_READ_UINT24_BE (&reader->data[reader->byte]);
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_peek_int24_le (GstByteReader * reader, gint32 * val)
-{
-  guint32 ret;
-
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  ret = GST_READ_UINT24_LE (&reader->data[reader->byte]);
-  if (ret & 0x00800000)
-    ret |= 0xff000000;
-
-  *val = ret;
-  return TRUE;
-}
-
-gboolean
-gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
-{
-  guint32 ret;
-
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < 3)
-    return FALSE;
-
-  ret = GST_READ_UINT24_BE (&reader->data[reader->byte]);
-  if (ret & 0x00800000)
-    ret |= 0xff000000;
-
-  *val = ret;
-  return TRUE;
-}
+GST_BYTE_READER_PEEK_GET(64,guint64,uint64_le)
+GST_BYTE_READER_PEEK_GET(64,guint64,uint64_be)
+GST_BYTE_READER_PEEK_GET(64,gint64,int64_le)
+GST_BYTE_READER_PEEK_GET(64,gint64,int64_be)
 
 /**
  * gst_byte_reader_get_float32_le:
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gfloat to store the result
  *
- * Read a 32 bit little endian integer into @val
+ * Read a 32 bit little endian floating point value into @val
  * and update the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1008,7 +755,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gfloat to store the result
  *
- * Read a 32 bit little endian integer into @val
+ * Read a 32 bit little endian floating point value into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1021,7 +768,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gfloat to store the result
  *
- * Read a 32 bit big endian integer into @val
+ * Read a 32 bit big endian floating point value into @val
  * and update the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1034,7 +781,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gfloat to store the result
  *
- * Read a 32 bit big endian integer into @val
+ * Read a 32 bit big endian floating point value into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1047,7 +794,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gdouble to store the result
  *
- * Read a 64 bit little endian integer into @val
+ * Read a 64 bit little endian floating point value into @val
  * and update the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1060,7 +807,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gdouble to store the result
  *
- * Read a 64 bit little endian integer into @val
+ * Read a 64 bit little endian floating point value into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1073,7 +820,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gdouble to store the result
  *
- * Read a 64 bit big endian integer into @val
+ * Read a 64 bit big endian floating point value into @val
  * and update the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1086,7 +833,7 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * @reader: a #GstByteReader instance
  * @val: Pointer to a #gdouble to store the result
  *
- * Read a 64 bit big endian integer into @val
+ * Read a 64 bit big endian floating point value into @val
  * but keep the current position.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
@@ -1094,60 +841,12 @@ gst_byte_reader_peek_int24_be (GstByteReader * reader, gint32 * val)
  * Since: 0.10.22
  */
 
-#define GST_BYTE_READER_READ_FLOATS(bits, type, TYPE) \
-gboolean \
-gst_byte_reader_get_float##bits##_le (GstByteReader *reader, g##type *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_##TYPE##_LE (&reader->data[reader->byte]); \
-  reader->byte += bits / 8; \
-  return TRUE; \
-} \
-gboolean \
-gst_byte_reader_get_float##bits##_be (GstByteReader *reader, g##type *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_##TYPE##_BE (&reader->data[reader->byte]); \
-  reader->byte += bits / 8; \
-  return TRUE; \
-} \
-gboolean \
-gst_byte_reader_peek_float##bits##_le (GstByteReader *reader, g##type *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_##TYPE##_LE (&reader->data[reader->byte]); \
-  return TRUE; \
-} \
-gboolean \
-gst_byte_reader_peek_float##bits##_be (GstByteReader *reader, g##type *val) \
-{ \
-  g_return_val_if_fail (reader != NULL, FALSE); \
-  g_return_val_if_fail (val != NULL, FALSE); \
-  \
-  if (gst_byte_reader_get_remaining (reader) < bits / 8) \
-    return FALSE; \
-  \
-  *val = GST_READ_##TYPE##_BE (&reader->data[reader->byte]); \
-  return TRUE; \
-}
+GST_BYTE_READER_PEEK_GET(32,gfloat,float32_le)
+GST_BYTE_READER_PEEK_GET(32,gfloat,float32_be)
+GST_BYTE_READER_PEEK_GET(64,gdouble,float64_le)
+GST_BYTE_READER_PEEK_GET(64,gdouble,float64_be)
 
-GST_BYTE_READER_READ_FLOATS (32, float, FLOAT);
-GST_BYTE_READER_READ_FLOATS (64, double, DOUBLE);
+/* *INDENT-ON* */
 
 /**
  * gst_byte_reader_get_data:
@@ -1168,15 +867,7 @@ gboolean
 gst_byte_reader_get_data (GstByteReader * reader, guint size,
     const guint8 ** val)
 {
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < size)
-    return FALSE;
-
-  *val = reader->data + reader->byte;
-  reader->byte += size;
-  return TRUE;
+  return _gst_byte_reader_get_data_inline (reader, size, val);
 }
 
 /**
@@ -1195,17 +886,10 @@ gst_byte_reader_get_data (GstByteReader * reader, guint size,
  * Since: 0.10.22
  */
 gboolean
-gst_byte_reader_peek_data (GstByteReader * reader, guint size,
+gst_byte_reader_peek_data (const GstByteReader * reader, guint size,
     const guint8 ** val)
 {
-  g_return_val_if_fail (reader != NULL, FALSE);
-  g_return_val_if_fail (val != NULL, FALSE);
-
-  if (gst_byte_reader_get_remaining (reader) < size)
-    return FALSE;
-
-  *val = reader->data + reader->byte;
-  return TRUE;
+  return _gst_byte_reader_peek_data_inline (reader, size, val);
 }
 
 /**
@@ -1225,13 +909,7 @@ gst_byte_reader_peek_data (GstByteReader * reader, guint size,
 gboolean
 gst_byte_reader_dup_data (GstByteReader * reader, guint size, guint8 ** val)
 {
-  const guint8 *cval = NULL;
-
-  if (!gst_byte_reader_get_data (reader, size, &cval))
-    return FALSE;
-
-  *val = g_memdup (cval, size);
-  return TRUE;
+  return _gst_byte_reader_dup_data_inline (reader, size, val);
 }
 
 /**
@@ -1279,7 +957,7 @@ gst_byte_reader_dup_data (GstByteReader * reader, guint size, guint8 ** val)
  * Since: 0.10.24
  */
 guint
-gst_byte_reader_masked_scan_uint32 (GstByteReader * reader, guint32 mask,
+gst_byte_reader_masked_scan_uint32 (const GstByteReader * reader, guint32 mask,
     guint32 pattern, guint offset, guint size)
 {
   const guint8 *data;
@@ -1317,7 +995,7 @@ gst_byte_reader_masked_scan_uint32 (GstByteReader * reader, guint32 mask,
 
 #define GST_BYTE_READER_SCAN_STRING(bits) \
 static guint \
-gst_byte_reader_scan_string_utf##bits (GstByteReader * reader) \
+gst_byte_reader_scan_string_utf##bits (const GstByteReader * reader) \
 { \
   guint len, off, max_len; \
   \
@@ -1463,7 +1141,8 @@ GST_BYTE_READER_SKIP_STRING (32);
  * Since: 0.10.24
  */
 gboolean
-gst_byte_reader_peek_string_utf8 (GstByteReader * reader, const gchar ** str)
+gst_byte_reader_peek_string_utf8 (const GstByteReader * reader,
+    const gchar ** str)
 {
   g_return_val_if_fail (reader != NULL, FALSE);
   g_return_val_if_fail (str != NULL, FALSE);
