@@ -50,7 +50,7 @@
  * <orderedlist>
  *   <listitem><para>
  *     first put some properties under control, by calling
- *     controller = g_object_control_properties(object, "prop1", "prop2",...);
+ *     controller = gst_object_control_properties (object, "prop1", "prop2",...);
  *   </para></listitem>
  *   <listitem><para>
  *     Get a #GstControlSource for the property and set it up.
@@ -97,7 +97,7 @@ struct _GstControllerPrivate
 };
 
 /* helper */
-
+#ifndef GST_REMOVE_DEPRECATED
 static void
 gst_controlled_property_add_interpolation_control_source (GstControlledProperty
     * self)
@@ -111,6 +111,7 @@ gst_controlled_property_add_interpolation_control_source (GstControlledProperty
   gst_control_source_bind (GST_CONTROL_SOURCE (csource), self->pspec);
   self->csource = csource;
 }
+#endif
 
 /*
  * gst_controlled_property_new:
@@ -135,16 +136,15 @@ gst_controlled_property_new (GObject * object, const gchar * name)
           g_object_class_find_property (G_OBJECT_GET_CLASS (object), name))) {
     GST_DEBUG ("  psec->flags : 0x%08x", pspec->flags);
 
-    /* check if this param is witable */
-    g_return_val_if_fail ((pspec->flags & G_PARAM_WRITABLE), NULL);
-    /* check if property is controlable */
-    g_return_val_if_fail ((pspec->flags & GST_PARAM_CONTROLLABLE), NULL);
-    /* check if this param is not construct-only */
-    g_return_val_if_fail (!(pspec->flags & G_PARAM_CONSTRUCT_ONLY), NULL);
+    /* check if this param is witable && controlable && !construct-only */
+    g_return_val_if_fail ((pspec->flags & (G_PARAM_WRITABLE |
+                GST_PARAM_CONTROLLABLE | G_PARAM_CONSTRUCT_ONLY)) ==
+        (G_PARAM_WRITABLE | GST_PARAM_CONTROLLABLE), NULL);
 
-    if ((prop = g_new0 (GstControlledProperty, 1))) {
+    if ((prop = g_slice_new (GstControlledProperty))) {
       prop->pspec = pspec;
       prop->name = pspec->name;
+      prop->csource = NULL;
       prop->disabled = FALSE;
       memset (&prop->last_value, 0, sizeof (GValue));
       g_value_init (&prop->last_value, G_PARAM_SPEC_VALUE_TYPE (prop->pspec));
@@ -169,7 +169,7 @@ gst_controlled_property_free (GstControlledProperty * prop)
   if (prop->csource)
     g_object_unref (prop->csource);
   g_value_unset (&prop->last_value);
-  g_free (prop);
+  g_slice_free (GstControlledProperty, prop);
 }
 
 /*
@@ -201,6 +201,58 @@ gst_controller_find_controlled_property (GstController * self,
   return NULL;
 }
 
+/*
+ * gst_controller_add_property:
+ * @self: the controller object or %NULL if none yet exists
+ * @object: object to bind the property
+ * @name: name of projecty in @object
+ * @ref_existing: pointer to flag that tracks if we need to ref an existng
+ *   controller still
+ *
+ * Creates a new #GstControlledProperty if there is none for property @name yet.
+ * In case this is the first controlled propery, it creates the controller as
+ * well.
+ *
+ * Returns: a newly created controller object or reffed existing one with the
+ * given property bound.
+ */
+static GstController *
+gst_controller_add_property (GstController * self, GObject * object,
+    const gchar * name, gboolean * ref_existing)
+{
+  /* test if this property isn't yet controlled */
+  if (!self || !gst_controller_find_controlled_property (self, name)) {
+    GstControlledProperty *prop;
+
+    /* create GstControlledProperty and add to self->propeties List */
+    if ((prop = gst_controlled_property_new (object, name))) {
+      /* if we don't have a controller object yet, now is the time to create one */
+      if (!self) {
+        self = g_object_newv (GST_TYPE_CONTROLLER, 0, NULL);
+        self->object = g_object_ref (object);
+        /* store the controller */
+        g_object_set_qdata (object, priv_gst_controller_key, self);
+        *ref_existing = FALSE;
+      } else {
+        /* only want one single _ref(), even for multiple properties */
+        if (*ref_existing) {
+          g_object_ref (self);
+          *ref_existing = FALSE;
+          GST_INFO ("returning existing controller");
+        }
+      }
+      self->properties = g_list_prepend (self->properties, prop);
+    }
+  } else {
+    GST_WARNING ("trying to control property %s again", name);
+    if (*ref_existing) {
+      g_object_ref (self);
+      *ref_existing = FALSE;
+    }
+  }
+  return self;
+}
+
 /* methods */
 
 /**
@@ -216,7 +268,6 @@ GstController *
 gst_controller_new_valist (GObject * object, va_list var_args)
 {
   GstController *self;
-  GstControlledProperty *prop;
   gboolean ref_existing = TRUE;
   gchar *name;
 
@@ -227,34 +278,7 @@ gst_controller_new_valist (GObject * object, va_list var_args)
   self = g_object_get_qdata (object, priv_gst_controller_key);
   /* create GstControlledProperty for each property */
   while ((name = va_arg (var_args, gchar *))) {
-    /* test if this property isn't yet controlled */
-    if (!self || !(prop = gst_controller_find_controlled_property (self, name))) {
-      /* create GstControlledProperty and add to self->propeties List */
-      if ((prop = gst_controlled_property_new (object, name))) {
-        /* if we don't have a controller object yet, now is the time to create one */
-        if (!self) {
-          self = g_object_new (GST_TYPE_CONTROLLER, NULL);
-          self->object = g_object_ref (object);
-          /* store the controller */
-          g_object_set_qdata (object, priv_gst_controller_key, self);
-          ref_existing = FALSE;
-        } else {
-          /* only want one single _ref(), even for multiple properties */
-          if (ref_existing) {
-            g_object_ref (self);
-            ref_existing = FALSE;
-            GST_INFO ("returning existing controller");
-          }
-        }
-        self->properties = g_list_prepend (self->properties, prop);
-      }
-    } else {
-      GST_WARNING ("trying to control property again");
-      if (ref_existing) {
-        g_object_ref (self);
-        ref_existing = FALSE;
-      }
-    }
+    self = gst_controller_add_property (self, object, name, &ref_existing);
   }
   va_end (var_args);
 
@@ -276,7 +300,6 @@ GstController *
 gst_controller_new_list (GObject * object, GList * list)
 {
   GstController *self;
-  GstControlledProperty *prop;
   gboolean ref_existing = TRUE;
   gchar *name;
   GList *node;
@@ -289,34 +312,7 @@ gst_controller_new_list (GObject * object, GList * list)
   /* create GstControlledProperty for each property */
   for (node = list; node; node = g_list_next (node)) {
     name = (gchar *) node->data;
-    /* test if this property isn't yet controlled */
-    if (!self || !(prop = gst_controller_find_controlled_property (self, name))) {
-      /* create GstControlledProperty and add to self->propeties List */
-      if ((prop = gst_controlled_property_new (object, name))) {
-        /* if we don't have a controller object yet, now is the time to create one */
-        if (!self) {
-          self = g_object_new (GST_TYPE_CONTROLLER, NULL);
-          self->object = g_object_ref (object);
-          /* store the controller */
-          g_object_set_qdata (object, priv_gst_controller_key, self);
-          ref_existing = FALSE;
-        } else {
-          /* only want one single _ref(), even for multiple properties */
-          if (ref_existing) {
-            g_object_ref (self);
-            ref_existing = FALSE;
-            GST_INFO ("returning existing controller");
-          }
-        }
-        self->properties = g_list_prepend (self->properties, prop);
-      }
-    } else {
-      GST_WARNING ("trying to control property again");
-      if (ref_existing) {
-        g_object_ref (self);
-        ref_existing = FALSE;
-      }
-    }
+    self = gst_controller_add_property (self, object, name, &ref_existing);
   }
 
   if (self)
@@ -459,7 +455,7 @@ gst_controller_remove_properties (GstController * self, ...)
 
 void
 gst_controller_set_property_disabled (GstController * self,
-    gchar * property_name, gboolean disabled)
+    const gchar * property_name, gboolean disabled)
 {
   GstControlledProperty *prop;
 
@@ -517,8 +513,8 @@ gst_controller_set_disabled (GstController * self, gboolean disabled)
  * Since: 0.10.14
  */
 gboolean
-gst_controller_set_control_source (GstController * self, gchar * property_name,
-    GstControlSource * csource)
+gst_controller_set_control_source (GstController * self,
+    const gchar * property_name, GstControlSource * csource)
 {
   GstControlledProperty *prop;
   gboolean ret = FALSE;
@@ -557,7 +553,8 @@ gst_controller_set_control_source (GstController * self, gchar * property_name,
  * Since: 0.10.14
  */
 GstControlSource *
-gst_controller_get_control_source (GstController * self, gchar * property_name)
+gst_controller_get_control_source (GstController * self,
+    const gchar * property_name)
 {
   GstControlledProperty *prop;
   GstControlSource *ret = NULL;
@@ -590,7 +587,7 @@ gst_controller_get_control_source (GstController * self, gchar * property_name)
  * property isn't handled by the controller
  */
 GValue *
-gst_controller_get (GstController * self, gchar * property_name,
+gst_controller_get (GstController * self, const gchar * property_name,
     GstClockTime timestamp)
 {
   GstControlledProperty *prop;
@@ -646,7 +643,9 @@ gst_controller_suggest_next_sync (GstController * self)
   g_mutex_lock (self->lock);
 
   /* TODO: Implement more logic, depending on interpolation mode
-   * and control points */
+   * and control points
+   * FIXME: we need playback direction
+   */
   ret = self->priv->last_sync + self->priv->control_rate;
 
   g_mutex_unlock (self->lock);
@@ -952,9 +951,10 @@ _gst_controller_class_init (GstControllerClass * klass)
 GType
 gst_controller_get_type (void)
 {
-  static GType type = 0;
+  static volatile gsize type = 0;
 
-  if (type == 0) {
+  if (g_once_init_enter (&type)) {
+    GType _type;
     static const GTypeInfo info = {
       sizeof (GstControllerClass),
       NULL,                     /* base_init */
@@ -967,7 +967,8 @@ gst_controller_get_type (void)
       (GInstanceInitFunc) _gst_controller_init, /* instance_init */
       NULL                      /* value_table */
     };
-    type = g_type_register_static (G_TYPE_OBJECT, "GstController", &info, 0);
+    _type = g_type_register_static (G_TYPE_OBJECT, "GstController", &info, 0);
+    g_once_init_leave (&type, _type);
   }
   return type;
 }
@@ -987,6 +988,7 @@ gst_controller_get_type (void)
  *
  * Returns: %TRUE for success
  */
+#ifndef GST_REMOVE_DEPRECATED
 static gboolean
 gst_controlled_property_set_interpolation_mode (GstControlledProperty * self,
     GstInterpolateMode mode)
@@ -1005,6 +1007,7 @@ gst_controlled_property_set_interpolation_mode (GstControlledProperty * self,
   return gst_interpolation_control_source_set_interpolation_mode (icsource,
       mode);
 }
+#endif
 
 /**
  * gst_controller_set:
@@ -1021,8 +1024,13 @@ gst_controlled_property_set_interpolation_mode (GstControlledProperty * self,
  * Returns: FALSE if the values couldn't be set (ex : properties not handled by controller), TRUE otherwise
  */
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
 gboolean
-gst_controller_set (GstController * self, gchar * property_name,
+gst_controller_set (GstController * self, const gchar * property_name,
+    GstClockTime timestamp, GValue * value);
+#endif
+gboolean
+gst_controller_set (GstController * self, const gchar * property_name,
     GstClockTime timestamp, GValue * value)
 {
   gboolean res = FALSE;
@@ -1065,8 +1073,13 @@ out:
  * Returns: %FALSE if the values couldn't be set (ex : properties not handled by controller), %TRUE otherwise
  */
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
 gboolean
-gst_controller_set_from_list (GstController * self, gchar * property_name,
+gst_controller_set_from_list (GstController * self, const gchar * property_name,
+    GSList * timedvalues);
+#endif
+gboolean
+gst_controller_set_from_list (GstController * self, const gchar * property_name,
     GSList * timedvalues)
 {
   gboolean res = FALSE;
@@ -1111,8 +1124,13 @@ out:
  * Returns: %FALSE if the values couldn't be unset (ex : properties not handled by controller), %TRUE otherwise
  */
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
 gboolean
-gst_controller_unset (GstController * self, gchar * property_name,
+gst_controller_unset (GstController * self, const gchar * property_name,
+    GstClockTime timestamp);
+#endif
+gboolean
+gst_controller_unset (GstController * self, const gchar * property_name,
     GstClockTime timestamp)
 {
   gboolean res = FALSE;
@@ -1154,8 +1172,12 @@ out:
  * Since: 0.10.5
  */
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
+gboolean gst_controller_unset_all (GstController * self,
+    const gchar * property_name);
+#endif
 gboolean
-gst_controller_unset_all (GstController * self, gchar * property_name)
+gst_controller_unset_all (GstController * self, const gchar * property_name)
 {
   GstControlledProperty *prop;
 
@@ -1194,8 +1216,12 @@ out:
  * Returns: a copy of the list, or %NULL if the property isn't handled by the controller
  */
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
+const GList *gst_controller_get_all (GstController * self,
+    const gchar * property_name);
+#endif
 const GList *
-gst_controller_get_all (GstController * self, gchar * property_name)
+gst_controller_get_all (GstController * self, const gchar * property_name)
 {
   const GList *res = NULL;
   GstControlledProperty *prop;
@@ -1237,9 +1263,14 @@ out:
  * Returns: %TRUE if the property is handled by the controller, %FALSE otherwise
  */
 #ifndef GST_REMOVE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
 gboolean
 gst_controller_set_interpolation_mode (GstController * self,
-    gchar * property_name, GstInterpolateMode mode)
+    const gchar * property_name, GstInterpolateMode mode);
+#endif
+gboolean
+gst_controller_set_interpolation_mode (GstController * self,
+    const gchar * property_name, GstInterpolateMode mode)
 {
   gboolean res = FALSE;
   GstControlledProperty *prop;
