@@ -180,23 +180,21 @@ gst_test_mono_source_class_init (GstTestMonoSourceClass * klass)
 static void
 gst_test_mono_source_base_init (GstTestMonoSourceClass * klass)
 {
-  static const GstElementDetails details = {
-    "Monophonic source for unit tests",
-    "Source/Audio/MonoSource",
-    "Use in unit tests",
-    "Stefan Kost <ensonic@users.sf.net>"
-  };
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_set_details (element_class, &details);
+  gst_element_class_set_details_simple (element_class,
+      "Monophonic source for unit tests",
+      "Source/Audio/MonoSource",
+      "Use in unit tests", "Stefan Kost <ensonic@users.sf.net>");
 }
 
 static GType
 gst_test_mono_source_get_type (void)
 {
-  static GType type = 0;
+  static volatile gsize test_mono_source_type = 0;
 
-  if (type == 0) {
+  if (g_once_init_enter (&test_mono_source_type)) {
+    GType type;
     static const GTypeInfo info = {
       (guint16) sizeof (GstTestMonoSourceClass),
       (GBaseInitFunc) gst_test_mono_source_base_init,   // base_init
@@ -212,8 +210,9 @@ gst_test_mono_source_get_type (void)
     type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstTestMonoSource", &info,
         0);
+    g_once_init_leave (&test_mono_source_type, type);
   }
-  return type;
+  return test_mono_source_type;
 }
 
 /* so we don't have to paste the gst_element_register into 50 places below */
@@ -535,6 +534,78 @@ GST_START_TEST (controller_controlsource_refcounts)
 
 GST_END_TEST;
 
+/* tests if we don't fail on empty controllers */
+GST_START_TEST (controller_controlsource_empty1)
+{
+  GstController *ctrl;
+  GstElement *elem;
+  GstControlSource *csource;
+
+  gst_controller_init (NULL, NULL);
+
+  elem = gst_element_factory_make ("testmonosource", "test_source");
+
+  /* that property should exist and should be controllable */
+  ctrl = gst_controller_new (G_OBJECT (elem), "ulong", NULL);
+  fail_unless (ctrl != NULL, NULL);
+
+  csource = (GstControlSource *) gst_interpolation_control_source_new ();
+  fail_unless (csource != NULL, NULL);
+
+  fail_unless (gst_controller_set_control_source (ctrl, "ulong", csource));
+
+  /* don't fail on empty control point lists */
+  gst_controller_sync_values (ctrl, 0 * GST_SECOND);
+
+  /* unref objects */
+  g_object_unref (csource);
+  g_object_unref (ctrl);
+  gst_object_unref (elem);
+}
+
+GST_END_TEST;
+
+/* tests if we don't fail on controllers that are empty again */
+GST_START_TEST (controller_controlsource_empty2)
+{
+  GstController *ctrl;
+  GstElement *elem;
+  GstInterpolationControlSource *csource;
+  GValue val = { 0, };
+
+  gst_controller_init (NULL, NULL);
+
+  elem = gst_element_factory_make ("testmonosource", "test_source");
+
+  /* that property should exist and should be controllable */
+  ctrl = gst_controller_new (G_OBJECT (elem), "ulong", NULL);
+  fail_unless (ctrl != NULL, NULL);
+
+  csource = gst_interpolation_control_source_new ();
+  fail_unless (csource != NULL, NULL);
+
+  fail_unless (gst_controller_set_control_source (ctrl, "ulong",
+          (GstControlSource *) csource));
+
+  /* set control values */
+  g_value_init (&val, G_TYPE_ULONG);
+  g_value_set_ulong (&val, 0);
+  gst_interpolation_control_source_set (csource, 0 * GST_SECOND, &val);
+
+  /* ... and unset the value */
+  gst_interpolation_control_source_unset (csource, 0 * GST_SECOND);
+
+  /* don't fail on empty control point lists */
+  gst_controller_sync_values (ctrl, 0 * GST_SECOND);
+
+  /* unref objects */
+  g_object_unref (csource);
+  g_object_unref (ctrl);
+  gst_object_unref (elem);
+}
+
+GST_END_TEST;
+
 /* test timed value handling without interpolation */
 GST_START_TEST (controller_interpolate_none)
 {
@@ -1079,7 +1150,7 @@ GST_START_TEST (controller_interpolation_linear_value_array)
   fail_unless (res, NULL);
 
   /* now pull in values for some timestamps */
-  values.property_name = "ulong";
+  values.property_name = (char *) "ulong";
   values.nbsamples = 3;
   values.sample_interval = GST_SECOND;
   values.values = (gpointer) g_new (gulong, 3);
@@ -1987,7 +2058,7 @@ GST_START_TEST (controller_refcount_new_list)
 
   /* that property should exist and should be controllable */
   elem = gst_element_factory_make ("testmonosource", "test_source");
-  list = g_list_append (NULL, "ulong");
+  list = g_list_append (NULL, (char *) "ulong");
   ctrl = gst_controller_new_list (G_OBJECT (elem), list);
   fail_unless (ctrl != NULL, NULL);
   GST_INFO ("controller->ref_count=%d", G_OBJECT (ctrl)->ref_count);
@@ -1998,8 +2069,8 @@ GST_START_TEST (controller_refcount_new_list)
 
   /* try the same property twice, make sure the refcount is still 1 */
   elem = gst_element_factory_make ("testmonosource", "test_source");
-  list = g_list_append (NULL, "ulong");
-  list = g_list_append (list, "ulong");
+  list = g_list_append (NULL, (char *) "ulong");
+  list = g_list_append (list, (char *) "ulong");
   ctrl = gst_controller_new_list (G_OBJECT (elem), list);
   fail_unless (ctrl != NULL, NULL);
   GST_INFO ("controller->ref_count=%d", G_OBJECT (ctrl)->ref_count);
@@ -2010,8 +2081,8 @@ GST_START_TEST (controller_refcount_new_list)
 
   /* try two properties, make sure the refcount is still 1 */
   elem = gst_element_factory_make ("testmonosource", "test_source");
-  list = g_list_append (NULL, "ulong");
-  list = g_list_append (list, "boolean");
+  list = g_list_append (NULL, (char *) "ulong");
+  list = g_list_append (list, (char *) "boolean");
   ctrl = gst_controller_new_list (G_OBJECT (elem), list);
   fail_unless (ctrl != NULL, NULL);
   GST_INFO ("controller->ref_count=%d", G_OBJECT (ctrl)->ref_count);
@@ -2025,7 +2096,7 @@ GST_START_TEST (controller_refcount_new_list)
   ctrl = gst_controller_new (G_OBJECT (elem), "ulong", NULL);
   fail_unless (ctrl != NULL, NULL);
   GST_INFO ("controller->ref_count=%d", G_OBJECT (ctrl)->ref_count);
-  list = g_list_append (NULL, "ulong");
+  list = g_list_append (NULL, (char *) "ulong");
   ctrl2 = gst_controller_new_list (G_OBJECT (elem), list);
   fail_unless (ctrl2 != NULL, NULL);
   fail_unless (ctrl == ctrl2, NULL);
@@ -2038,7 +2109,7 @@ GST_START_TEST (controller_refcount_new_list)
 
   /* try _new_list first and then _new */
   elem = gst_element_factory_make ("testmonosource", "test_source");
-  list = g_list_append (NULL, "ulong");
+  list = g_list_append (NULL, (char *) "ulong");
   ctrl = gst_controller_new_list (G_OBJECT (elem), list);
   fail_unless (ctrl != NULL, NULL);
   GST_INFO ("controller->ref_count=%d", G_OBJECT (ctrl)->ref_count);
@@ -2203,6 +2274,8 @@ gst_controller_suite (void)
   tcase_add_test (tc, controller_param_twice);
   tcase_add_test (tc, controller_finalize);
   tcase_add_test (tc, controller_controlsource_refcounts);
+  tcase_add_test (tc, controller_controlsource_empty1);
+  tcase_add_test (tc, controller_controlsource_empty2);
   tcase_add_test (tc, controller_interpolate_none);
   tcase_add_test (tc, controller_interpolate_trigger);
   tcase_add_test (tc, controller_interpolate_linear);
